spoon.ber.stream.zencoder

Package spoon :: Package ber :: Module stream :: Class zencoder |
[hide private]
[frames] | no frames]

# Class zencoder

source code

    object --+
             |
            zencoder

Instance Methods | [hide private]
`` | __init__(self, *types) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __call__(self, f)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *types) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __call__(self, f) (Call operator) | source code
None